@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: MIDI pitches for guitar chord voicings
 
-our $VERSION = '0.0400';
+our $VERSION = '0.0500';
 
 use strict;
 use warnings;
@@ -46,12 +46,14 @@ sub _build_chords {
         or die "Can't read $file: $!";
 
     while (my $row = $csv->getline($fh)) {
-        my $key = shift @$row;
+        my $chord = shift @$row;
+        my $fingering = shift @$row;
+        push @{ $data{$chord}{fingering} }, $fingering;
         my @notes;
         for my $r (@$row) {
             push @notes, $r if $r ne '';
         }
-        push @{ $data{$key} }, \@notes;
+        push @{ $data{$chord}{notes} }, \@notes;
     }
 
     close $fh;
@@ -70,14 +72,14 @@ sub transform {
     my @notes;
 
     if (defined $variation) {
-      my $pitches = $self->chords->{ 'C' . $chord_name }[$variation];
+      my $pitches = $self->chords->{ 'C' . $chord_name }{notes}[$variation];
 
       my $diff = $target - _lowest_c($pitches);
 
       @notes = map { $_ + $diff } @$pitches;
     }
     else {
-        for my $pitches (@{ $self->chords->{ 'C' . $chord_name } }) {
+        for my $pitches (@{ $self->chords->{ 'C' . $chord_name }{notes} }) {
             my $diff = $target - _lowest_c($pitches);
             push @notes, [ map { $_ + $diff } @$pitches ];
         }
@@ -108,7 +110,7 @@ sub voicings {
     $chord_name //= '';
     $format ||= '';
 
-    my $voicings = $self->chords->{ 'C' . $chord_name };
+    my $voicings = $self->chords->{ 'C' . $chord_name }{notes};
 
     if ($format) {
         my $temp;
@@ -144,7 +146,7 @@ MIDI::Chord::Guitar - MIDI pitches for guitar chord voicings
 
 =head1 VERSION
 
-version 0.0400
+version 0.0500
 
 =head1 SYNOPSIS
 
@@ -191,38 +193,6 @@ If not given, L<File::ShareDir> is used.
 
 Computed attribute available after construction.
 
-The known chord names are as follows:
-
-  '' (major)
-  aug
-  dim
-  dim7
-  m (minor)
-  m6
-  m7
-  m7b5
-  m7b5#9
-  m9
-  m11
-  maj7
-  maj7#11
-  maj9
-  sus2
-  sus4
-  6
-  6(9)
-  7
-  7#5
-  7#9
-  7b13
-  7b5
-  7b9
-  7b9b13
-  9
-  9sus4
-  11
-  13
-
 =head1 METHODS
 
 =head2 transform
@@ -285,7 +255,7 @@ used to create this.
 
 =head1 SEE ALSO
 
-The F<t/01-methods.t> and F<eg/autumn_leaves> files in this distribution
+The F<t/01-methods.t> and F<eg/*> files in this distribution
 
 L<File::ShareDir>
 
@@ -299,13 +269,15 @@ L<Text::CSV_XS>
 
 L<https://www.guitartricks.com/chords/C-chord> shapes
 
+L<https://www.oolimo.com/guitarchords/C> shapes
+
 =head1 AUTHOR
 
 Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Gene Boggs.
+This software is copyright (c) 2021 by Gene Boggs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
